============
Installation
============

At the command line::

    $ pip3 install iotronic_lightningrod
    $ lr_install

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv iotronic_lightningrod
    $ pip3 install iotronic_lightningrod